import QtQuick 1.0
import com.nokia.meego 1.0
import SocialNetworks 1.0

Page {
    id: article
    tools: toolbar

    orientationLock: PageOrientation.LockPortrait

    property int index: 0

    onStatusChanged: {
        if(menu.status == DialogStatus.Open || menu.status == DialogStatus.Opening)
            menu.close();
        if(status == PageStatus.Active)
            //window.setHeaderTitle(index+1 + "/" + news.rowCount )
            header.title = index+1 + "/" + news.rowCount

    }

    Component.onDestruction:  {
        console.log("page destroyed " + index);
    }


    ToolBarLayout {
        id: toolbar

        ToolIcon {
            platformIconId: "toolbar-back";
            onClicked: pageStack.pop();
        }
        ToolIcon {
            platformIconId: "toolbar-previous";
            visible: index == 0 ? false : true
            onClicked: {
                if(status != PageStatus.Active) return;

                var component = Qt.createComponent("Article.qml");
                //component.parent = pageStack.parent
                if(component.status == Component.Ready){
                    var object = component.createObject(pageStack, { "index" : index-1 });
                    pageStack.replace(object, {}, true)
                    destroy(1000)
                    enabled = false
                }
            }
        }
        ToolIcon {
            platformIconId: "toolbar-next";
            visible: index == news.rowCount-1 ? false : true
            onClicked: {
                if(status != PageStatus.Active) return;

                var component = Qt.createComponent("Article.qml");
                //component.parent = pageStack.parent
                if(component.status == Component.Ready){
                    var object = component.createObject(pageStack, { "index" : index+1 });
                    pageStack.replace(object, {}, true)
                    destroy(1000)
                    enabled = false
                }
            }
        }

        ToolIcon{
            platformIconId: "toolbar-view-menu"
            onClicked: {
                menu.open();
            }
        }
    }

    Menu {
        id: menu
        visualParent: article
        z: 100
        content: MenuLayout {
            MenuItem {
                text: news.dataForItemAt(index, 9) ? "Remove from Saved Articles" : "Save News Article"
                onClicked: {
                    //console.log("archive " + index)
                    console.log("save! " + feedID + " " + index)
                    if(news.dataForItemAt(index, 9)){
                        datamanager.setItemIsArchived(news.dataForItemAt(index, 1), false);
                        window.showToast("Article removed from archive.")
                        setText();
                    } else {
                        datamanager.setItemIsArchived(news.dataForItemAt(index, 1), true);
                        window.showToast("Article added to archive.")
                        setText();
                    }
                }

                function setText(){
                    if(news.dataForItemAt(index, 9)){
                        text = "Remove from Saved Articles"
                    } else {
                        text = "Save News Article"
                    }
                }

            }
            MenuItem {
                text: "View Complete News Article"
                onClicked: {
                    console.log("view " + index + " " + news.dataForItemAt(index, 4))
                    Qt.openUrlExternally(news.dataForItemAt(index, 4));
                }
            }
            MenuItem {
                text: "Share with others"
                //platformSubItemIndicator: true

                onClicked: {
                    //console.log("facebook " + index)
                    shareMenu.open();
                }
            }

        }
    }

    ContextMenu {
        id: shareMenu
        MenuLayout {
            MenuItem {
                text: "Facebook"
                onClicked: {
                    shareDialog.share(ShareDelegate.Facebook, news.dataForItemAt(index, 1));
                }
            }
            MenuItem {
                text: "Twitter"
                onClicked: {
                    shareDialog.share(ShareDelegate.Twitter, news.dataForItemAt(index, 1));
                }
            }
            MenuItem {
                text: "Google+"
                onClicked: {
                    shareDialog.share(ShareDelegate.GooglePlus, news.dataForItemAt(index, 1));
                }
            }
            MenuItem {
                text: "E-mail"
                onClicked: {
                    emaildelegate.sendStoryByEmail(news.dataForItemAt(index, 1));
                }
            }
            MenuItem {
                text: "Cancel"
                onClicked: {
                    close();
                }
            }

        }
    }

    Header {
        id: header
        z: 10
    }

    Rectangle {
        anchors.fill: parent
        color: "white"
    }

    Flickable {
        //anchors.fill: parent

        anchors.top: header.bottom
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom

        contentHeight: container.implicitHeight + 40
        contentWidth: width
        flickableDirection: Flickable.VerticalFlick

        Column {
            id: container
            anchors.fill: parent
            //width: parent.width
            //height: titleText.implicitHeight + linkText.implicitHeight + dateText.implicitHeight + separator.height + summaryText.implicitHeight + spacing*5
            anchors.margins: 10
            spacing: 10
            Text {
                id: titleText
                anchors.left: parent.left
                anchors.right: parent.right
                text: emaildelegate.stripXMLTags(news.dataForItemAt(index, 3))
                font.pixelSize: 34
                color: "#0000C0"
                wrapMode: Text.WordWrap
            }

            Text {
                id: linkText
                text: news.dataForItemAt(index,10)
                font.pixelSize: 24
                color: "black"
            }

            Text {
                id: dateText
                text: Qt.formatDateTime(news.dataForItemAt(index, 6), "ddd, d MMM yyyy HH:mm:ss");
                font.pixelSize: 24
                color: "black"

            }

            Rectangle {
                id: separator
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 15
                anchors.rightMargin: 15
                color: "gray"
                height: 2
            }

            Image {
                id: articleImage
                anchors.left: parent.left
                anchors.right: parent.right

                height: news.dataForItemAt(index, 7) === "" ? 0 : 320
                source: news.dataForItemAt(index, 7)

                fillMode: Image.PreserveAspectFit
            }

            Text {
                id: summaryText
                anchors.left: parent.left
                anchors.right: parent.right
                text: emaildelegate.stripXMLTags(news.dataForItemAt(index, 5))
                font.pixelSize: 26
                color: "black"
                wrapMode: Text.WordWrap
            }

        }

    }

}
