import QtQuick 1.0
import com.nokia.meego 1.0

Page {
    id: articlesPage
    tools: toolbar

    orientationLock: PageOrientation.LockPortrait

    Header {
        id: header
        z: 10
    }

    Component.onDestruction: {
        console.log("articles list destroyed");
    }

    Rectangle {
        color: "black"
        anchors.fill: parent
        z: -1
    }

    property string title: null

    onStatusChanged: {
        if(status == PageStatus.Active){
            //window.setHeaderTitle( title )
            header.title = title
        }
    }

    ToolBarLayout {
        id: toolbar
        ToolIcon {
            platformIconId: "toolbar-back";
            onClicked:{
                news.clear();
                pageStack.pop().destroy(1000);
            }
        }
        /*
        ToolIcon {
            platformIconId: "toolbar-refresh"
            onClicked: {
                feedmanager.fetchFromSelectedFeeds();
            }
        }
        */
    }

    ListView {
        id: articleList
        z: 1
        anchors.top: header.bottom
        anchors.bottom: statusBar.top
        anchors.right: parent.right
        anchors.left: parent.left

        spacing: 1

        model: news

        cacheBuffer: width * 4

        delegate: GalleryItem { }

        orientation: ListView.Vertical
        //snapMode: ListView.SnapOneItem

    }

    Rectangle {
        id: statusBar
        z:5
        //anchors.top: itemList.bottom
        anchors.bottom: parent.bottom

        property bool shown: false

        width: parent.width
        height: 0

        clip: true

        color: "#C0C0C0"

        Behavior on height {
            NumberAnimation { duration: 200 }
        }

        function show() {
            height = 60;
            shown = true
            busyIndicator.running = true
            busyIndicator.visible = true
        }

        function hide() {
            height = 0;
            shown = false;
            busyIndicator.running = false
            busyIndicator.visible = false
        }

        Text {
            id: statusText
            anchors.centerIn: parent
            font.pixelSize: 20
            color: "#000000"
        }

        BusyIndicator {
            id: busyIndicator
            width: 40
            height: 40
            running: false
            visible: false
            anchors.right: statusText.left
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
        }

        Connections {
            target: feedmanager
            onFetchingFeed: {
                statusText.text = "Fetching Feed: " + feedName
            }
            onStartedFetching: {
                statusBar.show();
                //networkActivityIndicator.start();
            }
            onFinishedFetching: {
                statusBar.hide();
                datamanager.reloadSelectedItems();
                //networkActivityIndicator.stop();
            }
        }
    }

}
