import QtQuick 1.0
import com.nokia.meego 1.0

Page {
    id: mainPage

    orientationLock: PageOrientation.LockPortrait

    Header {
        id: header
        anchors.top: parent.top
        z: 10
    }

    SearchBar {
        id: searchbar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: header.bottom
        height: 80
        z:10

        onSearchButtonClicked: {
            if(searchString === "") return;

            datamanager.selectItemsWithSearchString(searchString)
            var component = Qt.createComponent("ArticlesPage.qml")
            if(component.status == Component.Ready){
                var page = component.createObject(pageStack, { "title" : searchString })
                pageStack.push(page)
            }
        }
    }

    ListView {
        id: list
        //anchors.fill: parent
        anchors.top: searchbar.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top

        section.delegate: Component {
            Rectangle {
            //width: ListView.view.width
            width: list.width
            height: 60
            color: "#0000C0"

            Text {
                anchors.fill: parent
                anchors.margins: 2
                text: section
                color: "white"
                font.pixelSize: 32
                font.bold: true
                verticalAlignment: Text.AlignVCenter
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    console.log("section " + section + " clicked! load it");
                    datamanager.setSelectedCategory(section)
                    datamanager.selectItemsFromCategory(section);
                    var component = Qt.createComponent("ArticlesPage.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack, { "title" : section })
                        pageStack.push(page)
                    }
                }
                onCanceled: {
                    parent.color = "#0000C0"
                }
                onPressed: {
                    parent.color = "#00C0C0"
                }
                onReleased: {
                    parent.color = "#0000C0"
                }
            }
        }
        }
        section.property: "category"
        section.criteria: ViewSection.FullString


        delegate: FeedListDelegate {
            width: list.width
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var component = Qt.createComponent("ArticlesPage.qml")

                    if(component.status == Component.Ready){
                        console.log("try")
                        var page = component.createObject(pageStack, { "title" : name })
                        page.parent = pageStack.parent
                        pageStack.push(page)
                        datamanager.selectItemsFromFeedID(feedID);
                    }
                    console.log(component.errorString())
                    console.log("item clicked!");
                }
                onCanceled: {
                    parent.color = "white"
                }
                onPressed: {
                    parent.color = "#f9b700"
                }
                onReleased: {
                    parent.color = "white"
                }
            }
        }

        model: activeSources

        spacing: 1
        z: 1
    }

    tools: ToolBarLayout {
        id: mainToolbar
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                exitConfirmDialog.open();
                //pageStack.depth <= 1 ? Qt.quit() : pageStack.pop()
            }
        }
        ToolIcon {
            platformIconId: "toolbar-refresh"
            onClicked: feedmanager.fetchFromAllActiveFeeds();

        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            onClicked: {
                if(menu.status == DialogStatus.Open || menu.status == DialogStatus.Opening)
                    listMenu.close();
                else
                    listMenu.open();
            }
        }
        ToolIcon {
            platformIconId: "toolbar-settings"
            onClicked: {
                if(menu.status == DialogStatus.Open || menu.status == DialogStatus.Opening)
                    menu.close();
                else
                    menu.open();
            }
        }
    }

    Menu {
        id: listMenu
        visualParent: pageStack
        z: 2
        content: MenuLayout {
            MenuItem {
                text: "View Saved News Articles"
                onClicked: {
                    datamanager.selectArchivedItems();
                    var component = Qt.createComponent("ArticlesPage.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack, { "title" : "Archived" })
                        pageStack.push(page)
                    }
                    console.log("archived items clicked!");
                }
            }
            MenuItem {
                text: "View Gallery"
                onClicked: {
                    datamanager.selectItemsWithImages();
                    var component = Qt.createComponent("GalleryView.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack, { "title" : "Gallery" })
                        pageStack.push(page)
                    }
                    console.log("gallery items clicked!");
                }
            }
            MenuItem {
                text: "View Tag Cloud"
                onClicked: {
                    tagstore.printTags();
                    var component = Qt.createComponent("TagView.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack, { "title" : "Tags"})
                        pageStack.push(page)
                    }
                }
            }
        }
    }

    Menu {
        id: menu
        visualParent: pageStack
        z: 2
        content: MenuLayout {
            MenuItem {
                text: "Configure Feeds"
                onClicked: {
                    var component = Qt.createComponent("FeedConfigurationPage.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack)
                        pageStack.push(page)
                    }
                }
            }
            MenuItem {
                text: "Delete All News Items"
                onClicked: {
                    datamanager.clearAllItems();
                }
            }
            MenuItem {
                text: "About"
                onClicked: {
                    var component = Qt.createComponent("AboutPage.qml")
                    if(component.status == Component.Ready){
                        var page = component.createObject(pageStack)
                        pageStack.push(page)
                    }
                }
            }
        }
    }

    Rectangle {
        id: statusBar
        z: 5
        //anchors.top: itemList.bottom
        anchors.bottom: parent.bottom

        property bool shown: false

        width: parent.width
        height: 0

        clip: true

        color: "#C0C0C0"

        Behavior on height {
            NumberAnimation { duration: 200 }
        }

        function show() {
            height = 60;
            shown = true
            busyIndicator.running = true
            busyIndicator.visible = true
        }

        function hide() {
            height = 0;
            shown = false;
            busyIndicator.running = false
            busyIndicator.visible = false
        }

        Text {
            id: statusText
            anchors.centerIn: parent
            font.pixelSize: 20
            color: "#000000"
        }

        BusyIndicator {
            id: busyIndicator
            width: 40
            height: 40
            running: false
            visible: false
            anchors.right: statusText.left
            anchors.rightMargin: 10
            anchors.verticalCenter: parent.verticalCenter
        }

        Connections {
            target: feedmanager
            onFetchingFeed: {
                statusText.text = "Fetching Feed: " + feedName
            }
            onStartedFetching: {
                statusBar.show();
                //networkActivityIndicator.start();
            }
            onFinishedFetching: {
                statusBar.hide();
                //networkActivityIndicator.stop();
            }
        }
    }

    onStatusChanged: {
        if(status == PageStatus.Activating){
            header.title = "NewsCenter Global"
        }
    }

}
